# Git Tipps and Tools
There is a lot of ways how to use git and sometimes a working solution can be very helpful for everybody. So please share you experience and working solutions.

## HowTo add a specif ssh-key for your git account
Sometimes it might be useful to have different ssh-keys per project or have a special ssh-key just for github/gitlab.

Steps:
1. Generate a `ssh-keygen`
2. Add ssh-key to GitHub or GitLab account under settings
3. Write a `~/.ssh/config` file with a content like this

```
Host github.com
	HostName github.com
	User git
	IdentityFile ~/.ssh/id_rsa_for_git

Host gitlab.com
	HostName gitlab.com
	User git
	IdentityFile ~/.ssh/id_rsa_for_gitlab
```
Make sure that you adjust the `Hostname` accordingly and be sure that you use ssh in your git repo:
```bash
$ git remote -v
origin  git@github.com:USER/repo.git (fetch)
origin  git@github.com:USER/repo.git (push)
```
show no `https` in the urls.


## HowTo Sync a GitHub and a GitLab repository
It is easy to import a GitHub repo into GitLab and the otherway around. However, if you want to make sure you can have both repos at the same state, you need to syncronize them.

How to call: `./git-repos-sync [URL1] [URL2] [Branch]`
This means:
- `URL1` - Address of the first remote repository
- `URL2` - Address of the second remote repository
- The order of `URL1` or `URL2` does not matter.
- `Branch` is usually `master`

Different use cases:
1. You have **already** a local copy of either of the repositories (e.g. GitLab or GitHub)
2. You have no local copy of either repository.

### Case 1

```bash
cd dir-of-repo
# copy the script there
wget https://gitlab.phaidra.org/imgw/computer-resources/-/raw/master/Git/git-repos-sync
# make executable
chmod +x git-repos-sync
# execute the script
./git-repos-sync [URL] [URL] [Branch]
```

### Case 2

```bash
# Create a new folder to do the sync, can be any name
mkdir sync-repos
# copy the script there
wget https://gitlab.phaidra.org/imgw/computer-resources/-/raw/master/Git/git-repos-sync
# make executable
chmod +x git-repos-sync
# execute the script
./git-repos-sync [URL] [URL] [Branch]
```
